@@ -41,7 +41,7 @@ impl CanBeZeroizedOnDrop for BackendNonZeroScalar {
 //     type PointSize = <Point as RepresentableAsArray>::Size;
 // isn't leaking the `Point` (probably because type aliases are just inlined).
 
-#[derive(Clone, Copy, Debug, PartialEq)]
+#[derive(Clone, Copy, Debug, PartialEq, Default)]
 pub struct CurveScalar(BackendScalar);
 
 impl CurveScalar {
@@ -77,12 +77,6 @@ impl CurveScalar {
     }
 }
 
-impl Default for CurveScalar {
-    fn default() -> Self {
-        Self(BackendScalar::default())
-    }
-}
-
 impl DefaultIsZeroes for CurveScalar {}
 
 impl CanBeZeroizedOnDrop for CurveScalar {
