@@ -8,6 +8,13 @@
 //! Bob is able to combine these independent re-encryptions and decrypt the original message
 //! using his private key.
 //!
+//! ## Available feature flags
+//!
+//! * `default-rng` - adds methods that use the system RNG (default).
+//! * `serde-support` - implements `serde`-based serialization and deserialization.
+//! * `bindings-python` - adds a `bindings_python` submodule allowing dependent crates
+//!        to use and re-export some of the Python-wrapped Umbral types.
+//!
 //! # Usage
 //!
 //! ```
@@ -99,12 +106,20 @@
 #![forbid(unsafe_code)]
 #![warn(missing_docs, rust_2018_idioms, unused_qualifications)]
 #![no_std]
+// Allows us to mark items in the documentation as gated under specific features.
+#![cfg_attr(docsrs, feature(doc_cfg))]
+
+#[cfg(feature = "std")]
+extern crate std;
 
 extern crate alloc;
 
 #[cfg(feature = "bench-internals")]
 pub mod bench; // Re-export some internals for benchmarks.
 
+#[cfg(feature = "bindings-python")]
+pub mod bindings_python;
+
 mod capsule;
 mod capsule_frag;
 mod curve;
@@ -116,9 +131,11 @@ mod keys;
 mod params;
 mod pre;
 mod secret_box;
-mod serde;
 mod traits;
 
+#[cfg(feature = "serde-support")]
+mod serde;
+
 pub use capsule::{Capsule, OpenReencryptedError};
 pub use capsule_frag::{CapsuleFrag, CapsuleFragVerificationError, VerifiedCapsuleFrag};
 pub use dem::{DecryptionError, EncryptionError};
