@@ -51,6 +51,7 @@ pub fn encrypt_with_rng(
 
 /// A synonym for [`encrypt`] with the default RNG.
 #[cfg(feature = "default-rng")]
+#[cfg_attr(docsrs, doc(cfg(feature = "default-rng")))]
 pub fn encrypt(
     delegating_pk: &PublicKey,
     plaintext: &[u8],
@@ -113,6 +114,7 @@ pub fn generate_kfrags_with_rng(
 
 /// A synonym for [`generate_kfrags_with_rng`] with the default RNG.
 #[cfg(feature = "default-rng")]
+#[cfg_attr(docsrs, doc(cfg(feature = "default-rng")))]
 #[allow(clippy::too_many_arguments)]
 pub fn generate_kfrags(
     delegating_sk: &SecretKey,
@@ -148,11 +150,13 @@ pub fn reencrypt_with_rng(
     capsule: &Capsule,
     verified_kfrag: &VerifiedKeyFrag,
 ) -> VerifiedCapsuleFrag {
-    VerifiedCapsuleFrag::reencrypted(rng, capsule, &verified_kfrag.kfrag)
+    let kfrag = verified_kfrag.to_unverified();
+    VerifiedCapsuleFrag::reencrypted(rng, capsule, &kfrag)
 }
 
 /// A synonym for [`reencrypt_with_rng`] with the default RNG.
 #[cfg(feature = "default-rng")]
+#[cfg_attr(docsrs, doc(cfg(feature = "default-rng")))]
 pub fn reencrypt(capsule: &Capsule, verified_kfrag: &VerifiedKeyFrag) -> VerifiedCapsuleFrag {
     reencrypt_with_rng(&mut OsRng, capsule, verified_kfrag)
 }
@@ -176,8 +180,7 @@ pub fn decrypt_reencrypted(
 ) -> Result<Box<[u8]>, ReencryptionError> {
     let cfrags: Vec<_> = verified_cfrags
         .iter()
-        .cloned()
-        .map(|vcfrag| vcfrag.cfrag)
+        .map(|vcfrag| vcfrag.to_unverified())
         .collect();
     let key_seed = capsule
         .open_reencrypted(receiving_sk, delegating_pk, &cfrags)
